pub struct AllowEntry {
pub crate_name: Option<String>,
pub crate_key: Option<String>,
pub function: Option<String>,
}Expand description
A suppression rule from [[allow]] in .capsec.toml.
At least one of crate/crate_name or function must be set for the rule
to match anything. Both crate and crate_name keys are supported for ergonomics.
Fields
crate_name: Option<String>crate_key: Option<String>function: Option<String>Implementations
Sourceimpl AllowEntry
impl AllowEntry
Sourcepub fn effective_crate(&self) -> Option<&str>
pub fn effective_crate(&self) -> Option<&str>
Returns the crate name from either crate or crate_name key.