pub struct ExportedAuthority {
pub category: Category,
pub risk: Risk,
pub leaf_call: String,
pub is_transitive: bool,
}Expand description
A single authority finding associated with an exported function.
Fields
category: CategoryWhat kind of ambient authority this exercises.
risk: RiskHow dangerous this call is.
leaf_call: StringThe leaf authority call that this traces back to.
is_transitive: boolWhether this is a direct call in the function or transitively propagated.